#ifndef __SETTINGS_H
#define __SETTINGS_H

#define SER_BAUDRATE            (115200)
#define DEBUG              // Ausgabe von Debug Infos auf der seriellen Console
#define DEBUG_RCV_DATA 0    // Ausgabe von Debug Infos von empfang data
#define DEBUG_TX_DATA 0    // Ausgabe was gesendet wird; 0 oder 1
#define PA_LEVEL RF24_PA_HIGH
#define CHANNEL_HOP_TX 1
#define WITHWIFI 1
#define CHECK_CRC  0
#define UPDATETICK 8000
#define ZEROEXP 1
#define INTERRUPT 0
#define SNIFFER 0
#define TOLERANCE 10
//#define WITH_OTA              // mit OTA Support, also update der Firmware über WLan mittels IP/update

//Hardware configuration
#ifdef ESP8266
  #define RF1_CE_PIN  (D3)
  #define RF1_CS_PIN  (D8)
  #define RF1_IRQ_PIN (D4)
//#endif
//GPIO0  D3 -> IRQ
//GPIO2  D4 -> CE
//GPIO14 D5 -> SCK
//GPIO12 D6 -> MIso
//GPIO13 D7 -> MOsi
//GPIO15 D8 -> CSN
//#else
//  #define RF1_CE_PIN  (9)
//  #define RF1_CS_PIN  (10)
//  #define RF1_IRQ_PIN (2)
#endif

union longlongasbytes {
  uint64_t ull;
  uint8_t bytes[8];
};


uint64_t Serial2RadioID (uint64_t sn) {
//----------------------------------
  longlongasbytes llsn;
  longlongasbytes res;
  llsn.ull = sn;
  res.ull = 0;
  res.bytes[4] = llsn.bytes[0];
  res.bytes[3] = llsn.bytes[1];
  res.bytes[2] = llsn.bytes[2];
  res.bytes[1] = llsn.bytes[3];
  res.bytes[0] = 0x01;
  return res.ull;
}

// WR und DTU
#define DUMMY_RADIO_ID          ((uint64_t)0xDEADBEEF01ULL) 
#define SerialWR                0x106112345678ULL		 // <<<<<<<<<<<<<<<<<<<<<<< anpassen
uint64_t WR1_RADIO_ID           = Serial2RadioID (SerialWR);    // ((uint64_t)0x5279607201ULL);          
#define DTU_RADIO_ID            ((uint64_t)0x1234567801ULL)     // <<<<<<<<<<<<<<<<<<<<<<< anpassen
//#define DTU_RADIO_ID            ((uint64_t)0x7222841201ULL)
#define MAXPOWER 1100
#define MINPOWER 155  //watt under this, is the WR off


// Webserver
#define WEBSERVER_PORT      80

// Time Server
#define TIMESERVER_NAME "pool.ntp.org"
//#define TIMESERVER_NAME "fritz.box"

#ifdef WITH_OTA
    // OTA Einstellungen
    #define UPDATESERVER_PORT   WEBSERVER_PORT+1
    #define UPDATESERVER_DIR    "/update"							// mittels IP:81/update kommt man dann auf die OTA-Seite
    #define UPDATESERVER_USER   "username_für_OTA"					// <<<<<<<<<<<<<<<<<<<<<<< anpassen
    #define UPDATESERVER_PW     "passwort_für_OTA"					// <<<<<<<<<<<<<<<<<<<<<<< anpassen
#endif

// internes WLan
// PREFIXE dienen dazu, die eigenen WLans (wenn mehrere) vonfremden zu unterscheiden
// gehe hier davon aus, dass alle WLans das gleiche Passwort haben. Wenn nicht, dann mehre Passwörter hinterlegen
#define SSID_PREFIX1         "xxxx"						// <<<<<<<<<<<<<<<<<<<<<<< anpassen
//#define SSID_PREFIX2         "wlan2-Prefix"						// <<<<<<<<<<<<<<<<<<<<<<< anpassen
#define SSID_PASSWORD        "xxxx"					// <<<<<<<<<<<<<<<<<<<<<<< anpassen

// zur Berechnung von Sonnenauf- und -untergang
#define  geoBreite  49.2866
#define  geoLaenge  7.3416


#endif
